%define upstream_name    File-IsSorted
%define upstream_version 0.2.0

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Test files for being lexicographical sorted
License:    GPLv1+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/File/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(App::Cmd::Setup)
BuildRequires: perl(File::Spec)
BuildRequires: perl(IO::Handle)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(List::Util) >= 1.340.0
BuildRequires: perl(Module::Build) >= 0.280.0
BuildRequires: perl(Moo)
BuildRequires: perl(Path::Tiny)
BuildRequires: perl(Test::Builder::Module)
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(Test::Tester)
BuildRequires: perl(autodie)
BuildRequires: perl(locale)
BuildRequires: perl(parent)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This checks if the lines of files or filehandles are monotonically and
lexicographically increasing, (= are already sorted). It may consume less
RAM and be faster than the naive way of doing 'cmp myfile.txt <(LC_ALL=C
sort myfile.txt)' and it runs at O(n) instead of O(n*log(n)) time and keeps
O(1) lines instead of O(n).

$checker->is_filehandle_sorted({fh => $input_fh, id => "my-file.txt"});
    Checks if $input_fh is sorted - throws an exception if it is not sorted
    and returns true if it is.

$checker->is_file_sorted({path => "/path/to/file.txt", id =>
"my-file.txt"});
    Checks if the file at path is sorted - throws an exception if it is not
    sorted and returns true if it is.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Build.PL --installdirs=vendor

./Build

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*
/usr/bin/is-sorted
%{_mandir}/man1/is-sorted.1*

%changelog
* Sun May 15 2022 tv <tv> 0.2.0-1.mga9
+ Revision: 1858214
- update to 0.2.0

* Tue Mar 22 2022 umeabot <umeabot> 0.0.6-2.mga9
+ Revision: 1819771
- Mageia 9 Mass Rebuild

* Wed Apr 29 2020 tv <tv> 0.0.6-1.mga8
+ Revision: 1573086
- update to 0.0.6

* Thu Feb 20 2020 umeabot <umeabot> 0.0.5-2.mga8
+ Revision: 1545614
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 0.0.5-1.mga8
+ Revision: 1484955
- update to 0.0.5

* Mon Dec 16 2019 tv <tv> 0.0.4-1.mga8
+ Revision: 1468393
- update to 0.0.4

* Sun Dec 15 2019 shlomif <shlomif> 0.0.2-1.mga8
+ Revision: 1467375
- imported package perl-File-IsSorted

